@@ -1,24 +1,11 @@
 /*
   This file is part of the kcalutils library.
 
-  Copyright (c) 2001-2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2001-2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -39,15 +26,18 @@
 
 #include <QTimeZone>
 
-namespace KCalendarCore {
+namespace KCalendarCore
+{
 class Exception;
 }
 
-namespace KCalUtils {
+namespace KCalUtils
+{
 /**
   @brief Provides methods to format Incidence properties in various ways for display purposes.
 */
-namespace Stringify {
+namespace Stringify
+{
 Q_REQUIRED_RESULT KCALUTILS_EXPORT QString incidenceType(KCalendarCore::Incidence::IncidenceType type);
 
 /**
@@ -88,6 +78,6 @@ Q_REQUIRED_RESULT KCALUTILS_EXPORT QString tzUTCOffsetStr(const QTimeZone &tz);
 */
 Q_REQUIRED_RESULT KCALUTILS_EXPORT QString errorMessage(const KCalendarCore::Exception &exception);
 } // namespace Stringify
-} //namespace KCalUtils
+} // namespace KCalUtils
 
 #endif
